@@ -78,14 +78,21 @@ setGeneric("sparsify", function(funDataObject, minObs, maxObs) {standardGeneric(
 #' @keywords internal
 setMethod("sparsify", signature = "funData",
           function(funDataObject, minObs, maxObs){
+            
+            if(! all(is.numeric(minObs), length(minObs) == 1))
+              stop("Parameter 'minObs' must be passed as a number.") 
+            
+            if(! all(is.numeric(maxObs), length(maxObs) == 1))
+              stop("Parameter 'maxObs' must be passed as a number.") 
+            
             if(maxObs > nObsPoints(funDataObject))
-              stop("Sparsification: 'maxObs' must not exceed the maximal number of observations")
+              stop("'maxObs' must not exceed the maximal number of observations")
 
             if(minObs < 1)
-              stop("Sparsification: 'minObs' must be a positive integer!")
+              stop("'minObs' must be a positive integer!")
             
             if(maxObs < minObs)
-              stop("Sparsification: 'minObs' must be smaller or equal to 'maxObs'.")
+              stop("'minObs' must be smaller or equal to 'maxObs'.")
             
             sparseData <- funDataObject
 
@@ -175,6 +182,9 @@ setGeneric("addError", function(funDataObject, sd) {standardGeneric("addError")}
 #' @keywords internal
 setMethod("addError", signature = "funData",
           function(funDataObject, sd){
+            if(! all(is.numeric(sd), length(sd) == 1, sd > 0))
+              stop("Parameter 'sd' must be passed as a positive number.") 
+            
             ME <- array(stats::rnorm(prod(dim(funDataObject@X)), mean = 0, sd = sd),  dim(funDataObject@X))
             
             return(funDataObject + funData(funDataObject@argvals, ME))
@@ -363,6 +373,20 @@ efWiener <- function(argvals, M)
 #' par(oldPar)
 eFun <- function(argvals, M, ignoreDeg = NULL, type)
 {
+  if(! all(is.numeric(argvals), length(argvals) > 0))
+    stop("Parameter 'argvals' must be numeric.")
+  
+  if(! all(is.numeric(M), length(M) == 1, M > 0))
+    stop("Parameter 'M' must be passed as a positive number.") 
+  
+  if(!(is.null(ignoreDeg ) | all(is.numeric(ignoreDeg), ignoreDeg > 0)))
+    stop("Parameter 'ignoreDeg' must be either NULL or a vector of positive numbers.") 
+  
+  if(! all(is.character(type), length(type) == 1))
+     stop("Parameter 'type' must be passed as a string.")
+  
+  
+  
   ret <- switch(type,
                 Poly = efPoly(argvals, M),
                 PolyHigh = {
@@ -374,7 +398,7 @@ eFun <- function(argvals, M, ignoreDeg = NULL, type)
                 Fourier = efFourier(argvals, M, linear = FALSE),
                 FourierLin = efFourier(argvals, M, linear = TRUE),
                 Wiener = efWiener(argvals, M),
-                stop("eFun: choose either Poly, PolyHigh, Fourier, FourierLin or Wiener"))
+                stop("Choose either Poly, PolyHigh, Fourier, FourierLin or Wiener"))
   return(ret)
 }
 
@@ -421,11 +445,17 @@ eFun <- function(argvals, M, ignoreDeg = NULL, type)
 #' par(oldpar)
 eVal <- function(M, type)
 {
+  if(! all(is.numeric(M), length(M) == 1, M > 0))
+    stop("Parameter 'M' must be passed as a positive number.") 
+  
+  if(! all(is.character(type), length(type) == 1))
+    stop("Parameter 'type' must be passed as a string.")
+  
   ret <- switch(type,
                 linear = ((M+1) - (1:M)) / M,
                 exponential = exp(-(0:(M-1)) / 2),
                 wiener = 1/(pi/2 * (2 * (1:M) - 1))^2,
-                stop("eVal: choose either linear, exponential or wiener"))
+                stop("Choose either linear, exponential or wiener"))
   return(ret)
 }
 
@@ -498,9 +528,30 @@ eVal <- function(M, type)
 #' par(oldPar)
 simFunData <- function(argvals, M, eFunType, ignoreDeg = NULL, eValType, N)
 {
-  ### transform argvals to list, if necessary
-  if(!is.list(argvals))
-    argvals <- list(argvals)
+  ### check type of input parameters
+  if(! is.numeric(M))
+    stop("Parameter 'M' must be numeric.") 
+  
+  if(! is.character(eFunType))
+    stop("Parameter 'eFunType' must be passed as a string.")
+  
+  if(!(is.null(ignoreDeg ) | all(is.numeric(ignoreDeg), ignoreDeg > 0)))
+    stop("Parameter 'ignoreDeg' must be either NULL or a vector of positive numbers.") 
+  
+  if(! all(is.character(eValType), length(eValType) == 1))
+    stop("Parameter 'eValType' must be passed as a string.")
+  
+  if(! all(is.numeric(N), length(N) == 1, N > 0))
+    stop("Parameter 'N' must be passed as a positive number.") 
+  
+  # transform argvals to list, if necessary
+  if(! (is.list(argvals) & all(is.numeric(unlist(argvals)))))
+  {
+    if(is.numeric(argvals))
+      argvals <- list(argvals)
+    else
+      stop("Parameter 'argvals' must be either passed as a list or as a vector of numerics.")
+  }  
 
   ### check consistency of input data
   p <- length(argvals)
@@ -707,11 +758,32 @@ simFunData <- function(argvals, M, eFunType, ignoreDeg = NULL, eValType, N)
 #' par(oldPar)
 simMultiFunData <- function(type, argvals, M, eFunType, ignoreDeg = NULL, eValType, N)
 {
+  if(! all(is.character(type), length(type) == 1))
+    stop("Parameter 'type' must be passed as a string.")
+  
+  if(! (is.list(argvals) & all(is.numeric(unlist(argvals)))) )
+    stop("Parameter 'argvals' must be passed as a list of numerics.")
+  
+  if(! all(is.numeric(unlist(M))))
+    stop("Parameter 'M' must contain only numerics.") 
+  
+  if(! all(is.character(unlist(eFunType))))
+    stop("Parameter 'eFunType' must contain only strings.")
+  
+  if(!(is.null(ignoreDeg ) | all(is.numeric(ignoreDeg), ignoreDeg > 0)))
+    stop("Parameter 'ignoreDeg' must be either NULL or a vector of positive numbers.") 
+  
+  if(! all(is.character(eValType), length(eValType) == 1))
+    stop("Parameter 'eValType' must be passed as a string.")
+  
+  if(! all(is.numeric(N), length(N) == 1, N > 0))
+    stop("Parameter 'N' must be passed as a positive number.") 
+  
   # generate eigenfunctions
   trueFuns <- switch(type,
                      split = simMultiSplit(argvals, M, eFunType, ignoreDeg, eValType, N),
                      weighted = simMultiWeight(argvals, M, eFunType, ignoreDeg, eValType, N),
-                     stop("simMultiFunData: choose either 'split' or 'weighted' for the simulation of multivariate functional data.")
+                     stop("Choose either 'split' or 'weighted' for the simulation of multivariate functional data.")
   )
   
   # number of eigenfunctions generated
@@ -750,7 +822,7 @@ simMultiSplit <- function(argvals, M, eFunType, ignoreDeg = NULL, eValType, N)
 {
   # consistency check
   if(any( c(length(M), length(eFunType), length(eValType)) != 1) )
-    stop("simMultiSplit: argvals, M, eFunType, eValType must all be of length 1!")
+    stop("argvals, M, eFunType, eValType must all be of length 1!")
   
   # number of elements
   p <- length(argvals)
